pub struct Pool { /* private fields */ }Expand description
A pool of buffer frames with clock (second-chance FIFO) eviction.
Each pool manages a fixed set of frames. The buffer manager uses two pools: one for reads (70%) and one for writes (30%).
Implementations
Sourceimpl Pool
impl Pool
Sourcepub fn num_frames(&self) -> u32
pub fn num_frames(&self) -> u32
Get the number of frames in this pool.
Sourcepub fn find_evictable(&self) -> Option<FrameIdx>
pub fn find_evictable(&self) -> Option<FrameIdx>
Find an evictable frame using the clock (second-chance) algorithm.
Returns the index of an evictable frame, or None if all frames are pinned.
A frame is evictable if it is not pinned. If it has the recently_used flag,
we clear it and skip to the next frame (second chance).
We scan at most 2 * num_frames to ensure we complete a full cycle
with cleared flags before giving up.
Sourcepub fn find_empty(&self) -> Option<FrameIdx>
pub fn find_empty(&self) -> Option<FrameIdx>
Find the first empty (invalid page) frame.
Sourcepub fn dirty_count(&self) -> u32
pub fn dirty_count(&self) -> u32
Count the number of dirty frames.
Sourcepub fn pinned_count(&self) -> u32
pub fn pinned_count(&self) -> u32
Count the number of pinned frames.
Sourcepub fn loaded_count(&self) -> u32
pub fn loaded_count(&self) -> u32
Count the number of frames with valid pages loaded.