pub struct ChunkedNodeGroup { /* private fields */ }Expand description
A group of column chunks, one per column, holding up to
CHUNKED_NODE_GROUP_CAPACITY rows.
Implementations
Sourceimpl ChunkedNodeGroup
impl ChunkedNodeGroup
Sourcepub fn new(data_types: &[LogicalType], start_row_idx: u64) -> Self
pub fn new(data_types: &[LogicalType], start_row_idx: u64) -> Self
Create a new ChunkedNodeGroup with the given column types.
Sourcepub fn with_capacity(
data_types: &[LogicalType],
start_row_idx: u64,
capacity: u64,
) -> Self
pub fn with_capacity( data_types: &[LogicalType], start_row_idx: u64, capacity: u64, ) -> Self
Create a ChunkedNodeGroup with a custom capacity.
pub fn format(&self) -> NodeGroupFormat
pub fn set_format(&mut self, format: NodeGroupFormat)
pub fn residency_state(&self) -> ResidencyState
pub fn start_row_idx(&self) -> u64
pub fn capacity(&self) -> u64
pub fn num_rows(&self) -> u64
pub fn num_columns(&self) -> usize
pub fn is_full(&self) -> bool
pub fn remaining_capacity(&self) -> u64
pub fn column(&self, idx: usize) -> &ColumnChunk
pub fn column_mut(&mut self, idx: usize) -> &mut ColumnChunk
Sourcepub fn append_row(&mut self, values: &[Option<&[u8]>]) -> u64
pub fn append_row(&mut self, values: &[Option<&[u8]>]) -> u64
Append a row of raw byte values across all columns.
values[i] is Some(bytes) for a non-null value, None for null.
Returns the local row index within this chunked group.