pub struct ColumnChunkData { /* private fields */ }Expand description
In-memory columnar buffer for fixed-size values.
Implementations
Sourceimpl ColumnChunkData
impl ColumnChunkData
Sourcepub fn new(data_type: LogicalType, capacity: u64) -> Self
pub fn new(data_type: LogicalType, capacity: u64) -> Self
Create a new column chunk for the given type and capacity.
pub fn data_type(&self) -> &LogicalType
pub fn capacity(&self) -> u64
pub fn num_values(&self) -> u64
pub fn is_null(&self, pos: u64) -> bool
pub fn set_null(&mut self, pos: u64, is_null: bool)
pub fn null_mask(&self) -> &NullMask
pub fn null_mask_mut(&mut self) -> &mut NullMask
pub fn stats(&self) -> &ColumnChunkStats
pub fn metadata(&self) -> &ColumnChunkMetadata
pub fn set_metadata(&mut self, metadata: ColumnChunkMetadata)
pub fn residency_state(&self) -> ResidencyState
pub fn set_residency_state(&mut self, state: ResidencyState)
Sourcepub fn get_value<T: FixedSizeValue>(&self, pos: u64) -> T
pub fn get_value<T: FixedSizeValue>(&self, pos: u64) -> T
Get a typed value at the given position.
Sourcepub fn set_value<T: FixedSizeValue>(&mut self, pos: u64, val: T)
pub fn set_value<T: FixedSizeValue>(&mut self, pos: u64, val: T)
Set a typed value at the given position.
Sourcepub fn append_value<T: FixedSizeValue>(&mut self, val: T)
pub fn append_value<T: FixedSizeValue>(&mut self, val: T)
Append a typed value, incrementing num_values.
Sourcepub fn append_null(&mut self)
pub fn append_null(&mut self)
Append a null value, incrementing num_values.
Sourcepub fn scan_range<T: FixedSizeValue>(
&self,
start: u64,
count: u64,
) -> Vec<Option<T>>
pub fn scan_range<T: FixedSizeValue>( &self, start: u64, count: u64, ) -> Vec<Option<T>>
Scan a range of typed values, returning None for nulls.
Sourcepub fn num_bytes_per_value(&self) -> usize
pub fn num_bytes_per_value(&self) -> usize
Number of bytes per value.
Sourcepub fn set_num_values(&mut self, n: u64)
pub fn set_num_values(&mut self, n: u64)
Set num_values directly (used when bulk-loading).